Command-line interface for managing DIDs and keys CLI tool for managing DIDs and keys
This module provides command-line utilities for creating and managing Decentralized Identifiers (DIDs) and associated cryptographic keys.
This module is only available when the native feature is enabled.
Structs
- Cli
- TAP Agent CLI Tool for DID and Key Management
Enums
- Commands
- Available CLI commands
- Keys
Commands - Subcommands for key management
Functions
- run
- Run the CLI with the given arguments