Struct DefaultMessagePacker

pub struct DefaultMessagePacker { /* private fields */ }
Default implementation of the MessagePacker trait.

This implementation uses DIDComm for message packing and unpacking, providing secure communications with support for the different security modes defined in the TAP protocol.

Implementations

Source

impl DefaultMessagePacker

pub fn new( did_resolver: Arc<dyn SyncDIDResolver>, secrets_resolver: Arc<dyn DebugSecretsResolver>, ) -> Self

Create a new DefaultMessagePacker

Parameters
  • did_resolver - The DID resolver to use for resolving DIDs
  • secrets_resolver - The secrets resolver to use for cryptographic operations
pub async fn unpack_message<T: DeserializeOwned + Send>( &self, packed: &str, ) -> Result<T>

Unpack a message and parse it to the requested type