pub trait DebugSecretsResolver:
Debug
+ Send
+ Sync
+ AsAny {
// Required method
fn get_secrets_map(&self) -> &HashMap<String, Secret>;
}Expand description
A trait for resolving secrets for use with DIDComm.
This trait extends the built-in secrets resolver functionality from the DIDComm crate to provide additional functionality needed by the TAP Agent.
Required Methods
Sourcefn get_secrets_map(&self) -> &HashMap<String, Secret>
fn get_secrets_map(&self) -> &HashMap<String, Secret>
Get a reference to the secrets map for debugging purposes