PackOptions

Struct PackOptions 

pub struct PackOptions {
    pub security_mode: SecurityMode,
    pub recipient_kid: Option<String>,
    pub sender_kid: Option<String>,
}
Options for packing a message

Fields

security_mode: SecurityMode

Security mode to use

recipient_kid: Option<String>

Key ID of the recipient (for JWE)

sender_kid: Option<String>

Key ID of the sender (for JWS and JWE)

Implementations

Source

impl PackOptions

pub fn new() -> Self

Create new default packing options

pub fn with_plain(self) -> Self

Set to use plain mode (no security)

pub fn with_sign(self, sender_kid: &str) -> Self

Set to use signed mode with the given sender key ID

pub fn with_auth_crypt(self, sender_kid: &str, recipient_jwk: &Value) -> Self

Set to use auth-crypt mode with the given sender and recipient key IDs

pub fn security_mode(&self) -> SecurityMode

Get the security mode