pub struct UnpackedMessage {
pub plain_message: PlainMessage,
pub tap_message: Option<TapMessage>,
}Expand description
Result of unpacking a message containing both the PlainMessage and the parsed TAP message
Fields
plain_message: PlainMessageThe unpacked PlainMessage
tap_message: Option<TapMessage>The parsed TAP message (if it could be parsed)
Implementations
Sourceimpl UnpackedMessage
impl UnpackedMessage
Sourcepub fn new(plain_message: PlainMessage) -> Self
pub fn new(plain_message: PlainMessage) -> Self
Create a new UnpackedMessage
Sourcepub fn as_typed<T: TapMessageBody>(&self) -> Result<PlainMessage<T>>
pub fn as_typed<T: TapMessageBody>(&self) -> Result<PlainMessage<T>>
Try to get the message as a specific typed message
Sourcepub fn into_typed(self) -> PlainMessage<Value>
pub fn into_typed(self) -> PlainMessage<Value>
Convert to a typed message with untyped body