pub struct SecretHelperConfig {
pub command: String,
pub args: Vec<String>,
}Expand description
Configuration for a secret helper command
Fields
command: StringThe command to execute
args: Vec<String>Arguments to pass before the DID
Implementations
Sourceimpl SecretHelperConfig
impl SecretHelperConfig
Sourcepub fn from_command_string(s: &str) -> Result<Self>
pub fn from_command_string(s: &str) -> Result<Self>
Parse a command string into a SecretHelperConfig
Splits on whitespace. The first token is the command, the rest are arguments. The DID will be appended as the final argument at invocation time.