pub struct KeyStorage {
pub keys: HashMap<String, StoredKey>,
pub default_did: Option<String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
/* private fields */
}Expand description
A collection of stored keys
Fields
keys: HashMap<String, StoredKey>A map of DIDs to their stored keys
default_did: Option<String>The default DID to use when not specified
created_at: DateTime<Utc>Creation timestamp
updated_at: DateTime<Utc>Last update timestamp
Implementations
Sourceimpl KeyStorage
impl KeyStorage
Sourcepub fn find_by_label(&self, label: &str) -> Option<&StoredKey>
pub fn find_by_label(&self, label: &str) -> Option<&StoredKey>
Find a key by label
Sourcepub fn default_key_path() -> Option<PathBuf>
pub fn default_key_path() -> Option<PathBuf>
Get the default key path
Sourcepub fn load_default() -> Result<Self>
pub fn load_default() -> Result<Self>
Load keys from the default location
Sourcepub fn load_from_path(path: &Path) -> Result<Self>
pub fn load_from_path(path: &Path) -> Result<Self>
Load keys from a specific path
Sourcepub fn save_default(&self) -> Result<()>
pub fn save_default(&self) -> Result<()>
Save keys to the default location
Sourcepub fn save_to_path(&self, path: &Path) -> Result<()>
pub fn save_to_path(&self, path: &Path) -> Result<()>
Save keys to a specific path
On Unix systems, the file is created with restrictive permissions (0o600) to protect private key material from unauthorized access.
Sourcepub fn from_generated_key(key: &GeneratedKey) -> StoredKey
pub fn from_generated_key(key: &GeneratedKey) -> StoredKey
Convert a GeneratedKey to a StoredKey
Sourcepub fn from_generated_key_with_label(
key: &GeneratedKey,
label: &str,
) -> StoredKey
pub fn from_generated_key_with_label( key: &GeneratedKey, label: &str, ) -> StoredKey
Convert a GeneratedKey to a StoredKey with a specific label
Sourcepub fn create_agent_directory(
&self,
did: &str,
policies: &[String],
metadata: &HashMap<String, String>,
) -> Result<()>
pub fn create_agent_directory( &self, did: &str, policies: &[String], metadata: &HashMap<String, String>, ) -> Result<()>
Create agent directory and save policies/metadata files
On Unix systems, files are created with restrictive permissions (0o600) to protect sensitive agent configuration from unauthorized access.