pub struct PlainMessage<T = Value> {Show 13 fields
pub id: String,
pub typ: String,
pub type_: String,
pub body: T,
pub from: String,
pub to: Vec<String>,
pub thid: Option<String>,
pub pthid: Option<String>,
pub extra_headers: HashMap<String, Value>,
pub created_time: Option<u64>,
pub expires_time: Option<u64>,
pub from_prior: Option<String>,
pub attachments: Option<Vec<Attachment>>,
}Expand description
Wrapper for plain message. Provides helpers for message building and packing/unpacking. Adapted from https://github.com/sicpa-dlab/didcomm-rust/blob/main/src/message/message.rs
Fields
id: StringMessage id. Must be unique to the sender.
typ: StringOptional, if present it must be “application/didcomm-plain+json”
type_: StringMessage type attribute value MUST be a valid Message Type URI, that when resolved gives human readable information about the message. The attribute’s value also informs the content of the message, or example the presence of other attributes and how they should be processed.
body: TMessage body - strongly typed when T is specified.
from: StringSender identifier. The from attribute MUST be a string that is a valid DID or DID URL (without the fragment component) which identifies the sender of the message.
to: Vec<String>Identifier(s) for recipients. MUST be an array of strings where each element is a valid DID or DID URL (without the fragment component) that identifies a member of the message’s intended audience.
thid: Option<String>Uniquely identifies the thread that the message belongs to.
If not included the id property of the message MUST be treated as the value of the thid.
pthid: Option<String>If the message is a child of a thread the pthid
will uniquely identify which thread is the parent.
extra_headers: HashMap<String, Value>Custom message headers.
created_time: Option<u64>The attribute is used for the sender to express when they created the message, expressed in UTC Epoch Seconds (seconds since 1970-01-01T00:00:00Z UTC). This attribute is informative to the recipient, and may be relied on by protocols.
expires_time: Option<u64>The expires_time attribute is used for the sender to express when they consider the message to be expired, expressed in UTC Epoch Seconds (seconds since 1970-01-01T00:00:00Z UTC). This attribute signals when the message is considered no longer valid by the sender. When omitted, the message is considered to have no expiration by the sender.
from_prior: Option<String>from_prior is a compactly serialized signed JWT containing FromPrior value
attachments: Option<Vec<Attachment>>Implementations
Sourceimpl<T> PlainMessage<T>where
T: Serialize + DeserializeOwned,
impl<T> PlainMessage<T>where
T: Serialize + DeserializeOwned,
Sourcepub fn new(id: String, type_: String, body: T, from: String) -> PlainMessage<T>
pub fn new(id: String, type_: String, body: T, from: String) -> PlainMessage<T>
Create a new PlainMessage with the given body
Sourcepub fn with_recipients(self, to: Vec<String>) -> PlainMessage<T>
pub fn with_recipients(self, to: Vec<String>) -> PlainMessage<T>
Builder method to set recipients
Sourcepub fn with_recipient(self, recipient: &str) -> PlainMessage<T>
pub fn with_recipient(self, recipient: &str) -> PlainMessage<T>
Builder method to add a single recipient
Sourcepub fn with_thread_id(self, thid: Option<String>) -> PlainMessage<T>
pub fn with_thread_id(self, thid: Option<String>) -> PlainMessage<T>
Builder method to set thread ID
Sourcepub fn with_parent_thread_id(self, pthid: Option<String>) -> PlainMessage<T>
pub fn with_parent_thread_id(self, pthid: Option<String>) -> PlainMessage<T>
Builder method to set parent thread ID
Sourcepub fn with_expires_at(self, expires_time: u64) -> PlainMessage<T>
pub fn with_expires_at(self, expires_time: u64) -> PlainMessage<T>
Builder method to set expiration time
Sourcepub fn with_attachments(self, attachments: Vec<Attachment>) -> PlainMessage<T>
pub fn with_attachments(self, attachments: Vec<Attachment>) -> PlainMessage<T>
Builder method to add attachments
Sourcepub fn with_header(self, key: String, value: Value) -> PlainMessage<T>
pub fn with_header(self, key: String, value: Value) -> PlainMessage<T>
Builder method to add a custom header
Sourceimpl<T> PlainMessage<T>
impl<T> PlainMessage<T>
Sourcepub fn new_typed(body: T, from: &str) -> PlainMessage<T>
pub fn new_typed(body: T, from: &str) -> PlainMessage<T>
Create a new typed message
Sourcepub fn to_plain_message(self) -> Result<PlainMessage, Error>
pub fn to_plain_message(self) -> Result<PlainMessage, Error>
Convert to untyped PlainMessage for serialization/transport
Sourcepub fn extract_participants(&self) -> Vec<String>
pub fn extract_participants(&self) -> Vec<String>
Extract recipients based on the message body participants
Sourceimpl<T> PlainMessage<T>
impl<T> PlainMessage<T>
Sourcepub fn extract_participants_with_context(&self) -> Vec<String>
pub fn extract_participants_with_context(&self) -> Vec<String>
Extract participants using MessageContext
Sourcepub fn new_typed_with_context(body: T, from: &str) -> PlainMessage<T>
pub fn new_typed_with_context(body: T, from: &str) -> PlainMessage<T>
Create a typed message with automatic recipient detection
Sourcepub fn routing_hints(&self) -> RoutingHints
pub fn routing_hints(&self) -> RoutingHints
Get routing hints from the message body
Sourcepub fn transaction_context(&self) -> Option<TransactionContext>
pub fn transaction_context(&self) -> Option<TransactionContext>
Get transaction context from the message body
Sourceimpl PlainMessage
impl PlainMessage
Sourcepub fn from_untyped(plain_msg: PlainMessage) -> PlainMessage
pub fn from_untyped(plain_msg: PlainMessage) -> PlainMessage
Create a typed message from an untyped PlainMessage
Sourcepub fn parse_body<T>(self) -> Result<PlainMessage<T>, Error>where
T: TapMessageBody,
pub fn parse_body<T>(self) -> Result<PlainMessage<T>, Error>where
T: TapMessageBody,
Try to parse the body into a specific TAP message type
Sourcepub fn parse_tap_message(&self) -> Result<TapMessage, Error>
pub fn parse_tap_message(&self) -> Result<TapMessage, Error>
Parse into the TapMessage enum for runtime dispatch