pub struct AgentKeyManager { /* private fields */ }Expand description
Agent Key Manager implements the KeyManager trait using the agent key abstraction
Implementations
Sourceimpl AgentKeyManager
impl AgentKeyManager
Sourcepub fn get_generated_key(&self, did: &str) -> Result<GeneratedKey>
pub fn get_generated_key(&self, did: &str) -> Result<GeneratedKey>
Get a generated key (with DID document) by DID
Sourcepub async fn get_signing_key_type(&self, did: &str) -> Result<String>
pub async fn get_signing_key_type(&self, did: &str) -> Result<String>
Get the key type for a signing key (for debugging)
Sourcepub fn agent_key_from_generated(
&self,
key: &GeneratedKey,
) -> Result<LocalAgentKey>
pub fn agent_key_from_generated( &self, key: &GeneratedKey, ) -> Result<LocalAgentKey>
Create a LocalAgentKey from a GeneratedKey
Sourcepub fn get_private_key(&self, did: &str) -> Result<(Vec<u8>, KeyType)>
pub fn get_private_key(&self, did: &str) -> Result<(Vec<u8>, KeyType)>
Get the raw private key bytes and key type for a DID
Checks generated_keys first (raw bytes), falls back to extracting from the secrets JWK “d” parameter.
Sourcepub fn save_to_storage(&self) -> Result<()>
pub fn save_to_storage(&self) -> Result<()>
Save keys to storage if a storage path is configured
Sourcepub fn load_from_default_storage(self) -> Result<Self>
pub fn load_from_default_storage(self) -> Result<Self>
Load from default storage location
Sourcepub fn load_from_path(self, path: PathBuf) -> Result<Self>
pub fn load_from_path(self, path: PathBuf) -> Result<Self>
Load from a specific storage path
Sourcepub fn add_key_without_save(&self, key: &GeneratedKey) -> Result<()>
pub fn add_key_without_save(&self, key: &GeneratedKey) -> Result<()>
Add a key to the key manager without saving to storage This is useful when you plan to save to storage manually later
Sourcepub fn generate_key_without_save(
&self,
options: DIDGenerationOptions,
) -> Result<GeneratedKey>
pub fn generate_key_without_save( &self, options: DIDGenerationOptions, ) -> Result<GeneratedKey>
Generate a new key with the specified options without saving to storage This is useful when you plan to save to storage manually later
Sourcepub fn generate_web_did_without_save(
&self,
domain: &str,
options: DIDGenerationOptions,
) -> Result<GeneratedKey>
pub fn generate_web_did_without_save( &self, domain: &str, options: DIDGenerationOptions, ) -> Result<GeneratedKey>
Generate a new web DID with the specified domain and options without saving to storage This is useful when you plan to save to storage manually later