Struct AgentKeyManager

pub struct AgentKeyManager { /* private fields */ }
Agent Key Manager implements the KeyManager trait using the agent key abstraction

Implementations

Source

impl AgentKeyManager

pub fn new() -> Self

Create a new key manager

pub async fn get_signing_key_type(&self, did: &str) -> Result<String>

Get the key type for a signing key (for debugging)

pub fn agent_key_from_generated( &self, key: &GeneratedKey, ) -> Result<LocalAgentKey>

Create a LocalAgentKey from a GeneratedKey

pub fn save_to_storage(&self) -> Result<()>

Save keys to storage if a storage path is configured

pub fn load_from_default_storage(self) -> Result<Self>

Load from default storage location

pub fn load_from_path(self, path: PathBuf) -> Result<Self>

Load from a specific storage path