pub struct AgentKeyManager { /* private fields */ }Expand description
Agent Key Manager implements the KeyManager trait using the agent key abstraction
Implementations
Sourceimpl AgentKeyManager
impl AgentKeyManager
Sourcepub async fn get_signing_key_type(&self, did: &str) -> Result<String>
pub async fn get_signing_key_type(&self, did: &str) -> Result<String>
Get the key type for a signing key (for debugging)
Sourcepub fn agent_key_from_generated(
&self,
key: &GeneratedKey,
) -> Result<LocalAgentKey>
pub fn agent_key_from_generated( &self, key: &GeneratedKey, ) -> Result<LocalAgentKey>
Create a LocalAgentKey from a GeneratedKey
Sourcepub fn save_to_storage(&self) -> Result<()>
pub fn save_to_storage(&self) -> Result<()>
Save keys to storage if a storage path is configured
Sourcepub fn load_from_default_storage(self) -> Result<Self>
pub fn load_from_default_storage(self) -> Result<Self>
Load from default storage location
Sourcepub fn load_from_path(self, path: PathBuf) -> Result<Self>
pub fn load_from_path(self, path: PathBuf) -> Result<Self>
Load from a specific storage path