pub struct DefaultMessagePacker { /* private fields */ }Expand description
Default implementation of the MessagePacker trait.
This implementation uses DIDComm for message packing and unpacking, providing secure communications with support for the different security modes defined in the TAP protocol.
Implementations
Sourceimpl DefaultMessagePacker
impl DefaultMessagePacker
Sourcepub fn new(
did_resolver: Arc<dyn SyncDIDResolver>,
secrets_resolver: Arc<dyn DebugSecretsResolver>,
) -> Self
pub fn new( did_resolver: Arc<dyn SyncDIDResolver>, secrets_resolver: Arc<dyn DebugSecretsResolver>, ) -> Self
Create a new DefaultMessagePacker
Parameters
did_resolver- The DID resolver to use for resolving DIDssecrets_resolver- The secrets resolver to use for cryptographic operations
Sourcepub async fn unpack_message<T: DeserializeOwned + Send>(
&self,
packed: &str,
) -> Result<T>
pub async fn unpack_message<T: DeserializeOwned + Send>( &self, packed: &str, ) -> Result<T>
Unpack a message and parse it to the requested type