Message types and utilities Message types and utilities for the TAP Agent.
This module provides constants and types for working with TAP messages, including security modes and message type identifiers.
Structs
- Jwe
- JweHeader
- JweProtected
- JweRecipient
- Jws
- JWS (JSON Web Signature) supporting both General and Flattened serializations per RFC 7515.
- JwsProtected
- JwsSignature
Enums
- Ephemeral
Public Key - Security
Mode - Security mode for message packing and unpacking.
Constants
- DIDCOMM_
ENCRYPTED - DIDCOMM_
SIGNED - PRESENTATION_
MESSAGE_ TYPE - Message type identifiers used by the TAP Protocol These constant strings are used to identify different message types in the TAP protocol communications. Type identifier for Presentation messages
Functions
- base64_
decode_ flexible - Decode a base64-encoded string, accepting both standard base64 and base64url (with or without padding).