Module message

Message types and utilities Message types and utilities for the TAP Agent.

This module provides constants and types for working with TAP messages, including security modes and message type identifiers.

Structs

Jwe
JweHeader
JweProtected
JweRecipient
Jws
JwsProtected
JwsSignature

Enums

EphemeralPublicKey
SecurityMode
Security mode for message packing and unpacking.

Constants

DIDCOMM_ENCRYPTED
DIDCOMM_SIGNED
PRESENTATION_MESSAGE_TYPE
Message type identifiers used by the TAP Protocol These constant strings are used to identify different message types in the TAP protocol communications. Type identifier for Presentation messages